<?php

/**
 * League.Uri (https://uri.thephpleague.com/components/2.0/)
 *
 * @package    League\Uri
 * @subpackage League\Uri\Components
 * @author     Ignace Nyamagana Butera <nyamsprod@gmail.com>
 * @link       https://github.com/thephpleague/uri-components
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
declare (strict_types=1);
namespace GFPDF_Vendor\League\Uri\Components;

use GFPDF_Vendor\League\Uri\Contracts\FragmentInterface;
use GFPDF_Vendor\League\Uri\Contracts\UriComponentInterface;
use GFPDF_Vendor\League\Uri\Contracts\UriInterface;
use Psr\Http\Message\UriInterface as Psr7UriInterface;
use TypeError;
use function sprintf;
final class Fragment extends \GFPDF_Vendor\League\Uri\Components\Component implements \GFPDF_Vendor\League\Uri\Contracts\FragmentInterface
{
    private const REGEXP_FRAGMENT_ENCODING = '/
        (?:[^A-Za-z0-9_\\-\\.~\\!\\$&\'\\(\\)\\*\\+,;\\=%\\:\\/@\\?]+|
        %(?![A-Fa-f0-9]{2}))
    /x';
    /**
     * @var string|null
     */
    private $fragment;
    /**
     * New instance.
     *
     * @param mixed|null $fragment
     */
    public function __construct($fragment = null)
    {
        $this->fragment = $this->validateComponent($fragment);
    }
    /**
     * {@inheritDoc}
     */
    public static function __set_state(array $properties) : self
    {
        return new self($properties['fragment']);
    }
    /**
     * Create a new instance from a URI object.
     *
     * @param mixed $uri an URI object
     *
     * @throws TypeError If the URI object is not supported
     */
    public static function createFromUri($uri) : self
    {
        if ($uri instanceof \GFPDF_Vendor\League\Uri\Contracts\UriInterface) {
            return new self($uri->getFragment());
        }
        if (!$uri instanceof \Psr\Http\Message\UriInterface) {
            throw new \TypeError(\sprintf('The object must implement the `%s` or the `%s` interface.', \Psr\Http\Message\UriInterface::class, \GFPDF_Vendor\League\Uri\Contracts\UriInterface::class));
        }
        $component = $uri->getFragment();
        if ('' === $component) {
            return new self();
        }
        return new self($component);
    }
    /**
     * {@inheritDoc}
     */
    public function getContent() : ?string
    {
        return $this->encodeComponent($this->fragment, self::REGEXP_FRAGMENT_ENCODING);
    }
    /**
     * {@inheritDoc}
     */
    public function getUriComponent() : string
    {
        return (null === $this->fragment ? '' : '#') . $this->getContent();
    }
    /**
     * Returns the decoded fragment.
     */
    public function decoded() : ?string
    {
        return $this->fragment;
    }
    /**
     * {@inheritDoc}
     */
    public function withContent($content) : \GFPDF_Vendor\League\Uri\Contracts\UriComponentInterface
    {
        $content = self::filterComponent($content);
        if ($content === $this->getContent()) {
            return $this;
        }
        return new self($content);
    }
}
